- builtin: built-in configuration and RL algorithms
- renderer: pygame renderer
- c_lib.py: call c functions
- gridworld.py: gridworld interface
- model.py: base class for model
- environment.py: base class for environment
- utility.py: utilities
